/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.utils;

import com.google.common.collect.ImmutableList;
import com.google.common.io.LineProcessor;

import java.io.IOException;
import java.util.List;

/**
 * Implementation of the {@link LineProcessor} that will append each line into an array and
 * provide the array as the processor's result.
 */
public class LineCollector implements LineProcessor<List<String>> {

    final ImmutableList.Builder<String> listBuilder = ImmutableList.builder();

    @Override
    public boolean processLine(String line) throws IOException {
        listBuilder.add(line);
        return true; // process all lines.
    }

    @Override
    public List<String> getResult() {
        return listBuilder.build();
    }
}
